﻿This is a Markdown text file, see, for example, https://github.github.com/gfm/

# Data compiled from the ASA register to the Työelämätieto.fi website

This package contains the data used in the ASA register page visualisations of the Työelämätieto.fi site. The Finnish Institute of Occupational Health keeps an ASA register of persons exposed to carcinogenic substances and methods in their work.

The data includes the numbers of ASA exposure events reported by the employer. Due to privacy reasons, any groups where the number of cases is less than 5 have been excluded from the data.

The data includes all the groups with an adequate number of cases to display for at least one review year. This means, for instance, that any occupation that is not within the five biggest occupations in terms of the number of exposed persons in any of the years are not included in the data at all.

## Files in the package:

### Data files and explanations of the variables:

#### Commonly used variables:

- `year`: Year
- `profession`: Occupational class code according to Statistics Finland’s Occupational classification 2010 (values are number strings; number levels 1–5)
- `region`: Occupational safety and health region (values "01"–"05"), source: https://www.tyosuojelu.fi/tietoa-meista/yhteystiedot (accessed 9 June 2021)
- `industry`: Industry class code according to Statistics Finland’s industrial classification (TOL2008) at the letter level (values "A"–"X")
- `asaworkers`: The number of ASA exposed employees in the class in question
    - This does not consider the number of exposures reported for an individual during the year; it merely states whether a person has been reported as exposed to any exposure agent.

#### Files:

- `fragment1.csv`
  - A table indicating the number of persons reported as ASA exposed by year, occupational safety and health region and industry. A person is considered as ASA exposed if they have been reported as having been exposed to any ASA exposure agent during the year. If the same person has been registered as exposed in different industries or occupational safety and health regions in the same year, such exposure is included in the numbers of all the persons exposed in such industries and occupational safety and health regions.
  - Due to privacy reasons, any rows where the number of `asaworkers` is less than 5 have been excluded from the table.
  - Additional variables:
    - `workers`: The number of people in employment (thousands) in the occupational health and safety region, each year and in each industry.
      - Based on a table by Statistics Finland *115h -- People in employment (jobs) in the region by region, industry (TOL 2008), gender and year, 2007–2018*
      - source: https://pxnet2.stat.fi/PXWeb/pxweb/fi/StatFin/StatFin__vrm__tyokay/statfin_tyokay_pxt_115h.px/ (accessed 31 May 2021)
    - `proportion_1000`: The relative proportion of persons exposed compared to the number of people in employment in the region and in the industry for each year.
    - `region_mean`: The relative proportion of persons exposed to ASA agents compared to the number of people in employment in the region each year. 
      - This value is coded on the first row of each region and year (`industry="C"`); the value on other rows for the same region and year is 0.
- `finRegionsTopojson/`
  - A folder containing the geojson data used for map visualisation
  - For more information, see the `README.md` file in the folder.

- `fragment2top10.json`:
  - For each year, contains the ten occupations (Statistics Finland’s Occupational classification 2010) with the highest number of ASA exposure cases reported in all of Finland in the year in question as well as the numbers of exposures in these classes; in json format.
- `fragment2totalcases.json`:
  - The number of ASA exposure cases reported for each year in the different occupational classes, both in total and by gender; in json format.
  - Additional variables:
    - `"women"`: Number of women exposed
    - `"men"`: Number of men exposed
    - `"both"`: Total number of persons exposed
- `fragment2barplots.json`:
  - Contains the five ASA exposure agents for each year and occupational class causing the highest number of exposures in the group in question as well as the number of exposure events; in json format.


- `fragment3top10.json`:
  - Includes the top ten ASA exposure agents for each year causing the highest numbers of exposure events in the year in question in all of Finland as well as the number of exposure events to these exposure agents; in json format.
- `fragment3totalcases.json`:
  - Includes the numbers of exposure events to ASA different exposure agents for each year in total and by gender; in json format.
  - Additional variables: as in file `fragment2totalcases.json`.
- `fragment3barplots.json`:
  - Includes the five occupations where the numbers of exposure events to the exposure agent in question were the highest as well as the number of exposure events; in json format.

- `fragment4top10.json`:
  - Includes the ten industry classes (Statistics Finland’s Industrial classification 2008) for each year with the highest number of ASA exposure events in all of Finland in the year in question as well as the numbers of exposure events in such classes; in json format.
- `fragment4totalcases.json`:
  - Includes the numbers of ASA exposure events for each year in different occupational classes, in total and by gender; in json format.
- `fragment4barplots.json`:
  - Includes the five ASA exposure agents for each year, different industries and genders causing the highest number of exposure events in said group as well as the number of exposure events; in json format.
  - Additional variables: as in file `fragment2barplots.json`.

### Other files:

- `README.md`
  - This file

- `LICENSE.txt`
  - Licence information for the data
